@@ -106,10 +106,6 @@ static DBusMessage *get_properties(DBusConnection *conn,
 
 	DBG("conn %p", conn);
 
-	if (__connman_security_check_privilege(msg,
-					CONNMAN_SECURITY_PRIVILEGE_PUBLIC) < 0)
-		return __connman_error_permission_denied(msg);
-
 	reply = dbus_message_new_method_return(msg);
 	if (reply == NULL)
 		return NULL;
@@ -168,9 +164,7 @@ static DBusMessage *get_properties(DBusConnection *conn,
 	}
 
 
-	if (network->wifi.passphrase != NULL &&
-			__connman_security_check_privilege(msg,
-				CONNMAN_SECURITY_PRIVILEGE_SECRET) == 0)
+	if (network->wifi.passphrase != NULL)
 		connman_dbus_dict_append_basic(&dict, "WiFi.Passphrase",
 				DBUS_TYPE_STRING, &network->wifi.passphrase);
 
@@ -570,7 +564,7 @@ const char *__connman_network_get_ident(struct connman_network *network)
 	if (network->device == NULL)
 		return NULL;
 
-	return __connman_device_get_ident(network->device);
+	return connman_device_get_ident(network->device);
 }
 
 connman_bool_t __connman_network_get_weakness(struct connman_network *network)
